@@ -1,11 +1,10 @@
 """To check if your projects are up-to-date, you can let dfetch check it.
 
-For each project the local revision will be compared against the available
-revision on that branch. If there are new versions available this will be shown.
+For each project the local version (based on tag or revision) will be compared against
+the available version. If there are new versions available this will be shown.
 """
 
 import argparse
-import logging
 import os
 
 import dfetch.commands.command
@@ -13,8 +12,9 @@ import dfetch.manifest.manifest
 import dfetch.manifest.validate
 import dfetch.project
 import dfetch.util
+from dfetch.log import get_logger
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class Check(dfetch.commands.command.Command):
@@ -36,9 +36,7 @@ class Check(dfetch.commands.command.Command):
             exceptions = []
             for project in manifest.projects:
                 try:
-                    dfetch.project.make(
-                        project, logger.getChild(project.name)
-                    ).check_for_update()
+                    dfetch.project.make(project).check_for_update()
                 except RuntimeError as exc:
                     exceptions += [str(exc)]
 
